DefaultLoginService class
Default implementation of LoginService using AtOnline API
- Implemented types
Constructors
- DefaultLoginService(AtOnline api)
Properties
- api → AtOnline
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
completeLogin(
Map< String, dynamic> token) → Future<bool> -
Store token and fetch user details
override
-
fetchDynamicOptions(
String api) → Future -
Fetch data for dynamic select options
override
-
isUserLoggedIn(
) → bool -
Check if user is logged in
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
processOAuth2Login(
{required String oauth2Id, required String redirectUri, required String session}) → Future -
Process OAuth2 login - v2 format
override
-
submitLoginData(
{required String action, required String session, Map< String, String> ? formData}) → Future -
Submit login form data to AtOnline API
override
-
toString(
) → String -
A string representation of this object.
inherited
-
uploadFiles(
Map< String, File> files, Map<String, dynamic> fileFields) → Future<void> -
Upload files associated with the login
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited