LoginService class abstract

Service responsible for handling AtOnline login API interactions

Implementers

Constructors

LoginService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

completeLogin(Map<String, dynamic> token) Future<bool>
Store token and fetch user details
fetchDynamicOptions(String api) Future
Fetch data for dynamic select options
isUserLoggedIn() bool
Check if user is logged in
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
processOAuth2Login({required String oauth2Id, required String redirectUri, required String session}) Future
Process OAuth2 login - v2 format
submitLoginData({required String action, required String session, Map<String, String>? formData}) Future
Submit login form data to AtOnline API
toString() String
A string representation of this object.
inherited
uploadFiles(Map<String, File> files, Map<String, dynamic> fileFields) Future<void>
Upload files associated with the login

Operators

operator ==(Object other) bool
The equality operator.
inherited