DefaultImagePickerService class
Default implementation of ImagePickerService using image_picker package
- Implemented types
Constructors
- DefaultImagePickerService({ImagePicker? picker})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pickImageFromGallery(
) → Future< XFile?> -
Selects an image from the gallery
override
-
takePhoto(
) → Future< XFile?> -
Takes a photo using the camera
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited